"""Schemas for API Responses."""
from typing import Optional, TypeVar

from pydantic import AnyUrl, BaseModel, Field

T = TypeVar("T")

__all__ = ["PagingMixin", "PagingLinks", "Paging"]


class PagingMixin(BaseModel):
    limit: Optional[int] = Field(25, ge=0, le=1000)
    offset: Optional[int] = None


class PagingLinks(BaseModel):
    """Schema for holding paging links."""

    first: Optional[AnyUrl] = None
    previous: Optional[AnyUrl] = None
    next: Optional[AnyUrl] = None
    last: Optional[AnyUrl] = None


class Paging(BaseModel):
    """Schema for paging information."""

    page: Optional[int] = None
    items: Optional[int] = None
    total_pages: Optional[int] = None
    total_items: Optional[int] = None
    links: Optional[PagingLinks] = None
